@@ -6,7 +6,7 @@ use warnings;
 use Carp            ();
 use Padre::Document ();
 
-our $VERSION = '0.23';
+our $VERSION = '0.24';
 our @ISA     = 'Padre::Document';
 
 
@@ -16,23 +16,15 @@ our @ISA     = 'Padre::Document';
 #####################################################################
 # Padre::Document::JavaScript Methods
 
+# Copied from Padre::Document::Perl
 sub get_functions {
 	my $self = shift;
 	my $text = $self->text_get;
-	
-	my %nlCharTable = ( UNIX => "\n", WIN => "\r\n", MAC => "\r" );
-	my $nlchar = $nlCharTable{ $self->get_newline_type };
-	
-	return $text =~ m/${nlchar}function\s+(\w+(?:::\w+)*)/g;
+	return $text =~ m/[\012\015]function\s+(\w+(?:::\w+)*)/g;
 }
 
 sub get_function_regex {
-	my ( $self, $sub ) = @_;
-	
-	my %nlCharTable = ( UNIX => "\n", WIN => "\r\n", MAC => "\r" );
-	my $nlchar = $nlCharTable{ $self->get_newline_type };
-	
-	return qr!(?:^|${nlchar})function\s+$sub\b!;
+	return qr/(?:(?<=^)function\s+$_[1]|(?<=[\012\0125])function\s+$_[1])\b/;
 }
 
 sub comment_lines_str { return '//' }
